bayespy.inference.vmp.nodes.poisson.PoissonMoments.compute_fixed_moments
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonMoments.compute_fixed_moments